==> chromium_99.0.4844.74.orig.tar.xz: chromium-99.0.4844.74/ash/services/ime/public/cpp/rulebased/def/te_phone.cc <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ash/services/ime/public/cpp/rulebased/def/te_phone.h"

#include "base/cxx17_backports.h"

namespace te_phone {

const char* kId = "te_phone";
bool kIs102 = false;
const char* kTransforms[] = {u8"([\u0c15-\u0c39])\u001d?u",
                             u8"\\1\u0c4c",
                             u8"\u0c4a\u001d?o",
                             u8"\u0c4b",
                             u8"\u0c4d\u001d?O",
                             u8"\u0c4b",
                             u8"\u0c4d\u001d?o",
                             u8"\u0c4a",
                             u8"([\u0c15-\u0c39])\u001d?i",
                             u8"\\1\u0c48",
                             u8"\u0c46\u001d?e",
                             u8"\u0c40",
                             u8"\u0c4d\u001d?E",
                             u8"\u0c47",
                             u8"\u0c4d\u001d?e",
                             u8"\u0c46",
                             u8"\u0c4d\u0c33\u0c4d\u0c33\u0c4d\u001d?I",
                             u8"\u0c63",
                             u8"\u0c4d\u0c33\u0c4d\u001d?\\^I",
                             u8"\u0c63",
                             u8"\u0c4d\u0c33\u0c4d\u0c33\u0c4d\u001d?i",
                             u8"\u0c62",
                             u8"\u0c4d\u0c33\u0c4d\u001d?\\^i",
                             u8"\u0c62",
                             u8"\u0c43\u001d?I",
                             u8"\u0c44",
                             u8"\u0c43\u001d?\\^I",
                             u8"\u0c44",
                             u8"\u0c43\u001d?R",
                             u8"\u0c44",
                             u8"\u0c43\u001d?\\^i",
                             u8"\u0c43",
                             u8"\u0c44\u001d?i",
                             u8"\u0c43",
                             u8"\u0c4d\u001d?R",
                             u8"\u0c43",
                             u8"\u0c41\u001d?u",
                             u8"\u0c42",
                             u8"\u0c4d\u001d?U",
                             u8"\u0c42",
                             u8"\u0c4d\u001d?u",
                             u8"\u0c41",
                             u8"\u0c3f\u001d?i",
                             u8"\u0c40",
                             u8"\u0c4d\u001d?I",
                             u8"\u0c40",
                             u8"\u0c4d\u001d?i",
                             u8"\u0c3f",
                             u8"([\u0c15-\u0c39])\u001d?a",
                             u8"\\1\u0c3e",
                             u8"\u0c4d\u001d?A",
                             u8"\u0c3e",
                             u8"\u0c4d\u001d?a",
                             u8"",
                             u8"\\.a",
                             u8"\u0c3d",
                             u8"\\.m",
                             u8"\u0c02",
                             u8"\\.z",
                             u8"",
                             u8"\\.N",
                             u8"\u0c01",
                             u8"\u0c4d\u001d?\\.h",
                             u8"\u0c4d\u200c",
                             u8"\\.h",
                             u8"\u0c4d\u200c",
                             u8"@M",
                             u8"\u0c02",
                             u8"@h",
                             u8"\u0c03",
                             u8"@2",
                             u8"\u0c3d",
                             u8"M",
                             u8"\u0c02",
                             u8"H",
                             u8"\u0c03",
                             u8"\u0c15\u0c4d\u001d?H",
                             u8"\u0cf1",
                             u8"\u0c2a\u0c4d\u001d?H",
                             u8"\u0cf2",
                             u8"\u0c05\u001d?u",
                             u8"\u0c14",
                             u8"\u0c12\u001d?o",
                             u8"\u0c13",
                             u8"O",
                             u8"\u0c13",
                             u8"o",
                             u8"\u0c12",
                             u8"\u0c05\u001d?i",
                             u8"\u0c10",
                             u8"\u0c0e\u001d?e",
                             u8"\u0c08",
                             u8"E",
                             u8"\u0c0f",
                             u8"e",
                             u8"\u0c0e",
                             u8"\u0c33\u0c4d\u0c33\u0c4d\u001d?I",
                             u8"\u0c61",
                             u8"\u0c33\u0c4d\u001d?\\^I",
                             u8"\u0c61",
                             u8"\u0c33\u0c4d\u0c33\u0c4d\u001d?i",
                             u8"\u0c0c",
                             u8"\u0c33\u0c4d\u001d?i",
                             u8"\u0c0c",
                             u8"\u0c60\u001d?I",
                             u8"\u0c60",
                             u8"\u0c0b\u001d?R",
                             u8"\u0c60",
                             u8"R",
                             u8"\u0c0b",
                             u8"\u0c09\u001d?u",
                             u8"\u0c0a",
                             u8"U",
                             u8"\u0c0a",
                             u8"u",
                             u8"\u0c09",
                             u8"\u0c07\u001d?i",
                             u8"\u0c08",
                             u8"I",
                             u8"\u0c08",
                             u8"i",
                             u8"\u0c07",
                             u8"A",
                             u8"\u0c06",
                             u8"\u0c05\u001d?a",
                             u8"\u0c06",
                             u8"a",
                             u8"\u0c05",
                             u8"\u0c15\u0c4d\u0c37\u0c4d\u001d?h",
                             u8"\u0c15\u0c4d\u0c37\u0c4d",
                             u8"\u0c17\u0c4d\u001d?Y",
                             u8"\u0c1c\u0c4d\u0c1e\u0c4d",
                             u8"\u0c1c\u0c4d\u001d?n",
                             u8"\u0c1c\u0c4d\u0c1e\u0c4d",
                             u8"\u0c15\u0c4d\u0c38\u0c4d\u001d?h",
                             u8"\u0c15\u0c4d\u0c37\u0c4d",
                             u8"\u0c15\u0c4d\u001d?S",
                             u8"\u0c15\u0c4d\u0c37\u0c4d",
                             u8"x",
                             u8"\u0c15\u0c4d\u0c37\u0c4d",
                             u8"h",
                             u8"\u0c39\u0c4d",
                             u8"\u0c36\u0c4d\u001d?h",
                             u8"\u0c37\u0c4d",
                             u8"S",
                             u8"\u0c36\u0c4d",
                             u8"z",
                             u8"\u0c36\u0c4d",
                             u8"\u0c38\u0c4d\u001d?h",
                             u8"\u0c36\u0c4d",
                             u8"s",
                             u8"\u0c38\u0c4d",
                             u8"v",
                             u8"\u0c35\u0c4d",
                             u8"w",
                             u8"\u0c35\u0c4d",
                             u8"L",
                             u8"\u0c33\u0c4d",
                             u8"\\.L",
                             u8"\u0c33\u0c4d",
                             u8"l",
                             u8"\u0c32\u0c4d",
                             u8"r",
                             u8"\u0c30\u0c4d",
                             u8"\\.r",
                             u8"\u0c31\u0c4d",
                             u8"y",
                             u8"\u0c2f\u0c4d",
                             u8"~N",
                             u8"\u0c19\u0c4d",
                             u8"\u0c17\u0c4d\u001d?h",
                             u8"\u0c18\u0c4d",
                             u8"G",
                             u8"\u0c18\u0c4d",
                             u8"\\.g",
                             u8"\u0c17\u0c4d",
                             u8"g",
                             u8"\u0c17\u0c4d",
                             u8"\\.K",
                             u8"\u0c16\u0c4d",
                             u8"K",
                             u8"\u0c16\u0c4d",
                             u8"\u0c15\u0c4d\u001d?h",
                             u8"\u0c16\u0c4d",
                             u8"q",
                             u8"\u0c15\u0c4d",
                             u8"k",
                             u8"\u0c15\u0c4d",
                             u8"~n",
                             u8"\u0c1e\u0c4d",
                             u8"\u0c1c\u0c4d\u001d?h",
                             u8"\u0c1d\u0c4d",
                             u8"J",
                             u8"\u0c1d\u0c4d",
                             u8"\\.j",
                             u8"\u0c1c\u0c4d",
                             u8"j",
                             u8"\u0c1c\u0c4d",
                             u8"\u0c1a\u0c4d\u001d?h",
                             u8"\u0c1b\u0c4d",
                             u8"Ch",
                             u8"\u0c1b\u0c4d",
                             u8"C",
                             u8"\u0c1b\u0c4d",
                             u8"ch",
                             u8"\u0c1a\u0c4d",
                             u8"c",
                             u8"\u0c1a\u0c4d",
                             u8"N",
                             u8"\u0c23\u0c4d",
                             u8"\u0c21\u0c4d\u001d?h",
                             u8"\u0c22\u0c4d",
                             u8"\\.D",
                             u8"\u0c21\u0c4d",
                             u8"D",
                             u8"\u0c21\u0c4d",
                             u8"\u0c1f\u0c4d\u001d?h",
                             u8"\u0c20\u0c4d",
                             u8"T",
                             u8"\u0c1f\u0c4d",
                             u8"n",
                             u8"\u0c28\u0c4d",
                             u8"\u0c26\u0c4d\u001d?h",
                             u8"\u0c27\u0c4d",
                             u8"d",
                             u8"\u0c26\u0c4d",
                             u8"\u0c24\u0c4d\u001d?h",
                             u8"\u0c25\u0c4d",
                             u8"t",
                             u8"\u0c24\u0c4d",
                             u8"m",
                             u8"\u0c2e\u0c4d",
                             u8"\u0c2c\u0c4d\u001d?h",
                             u8"\u0c2d\u0c4d",
                             u8"B",
                             u8"\u0c2d\u0c4d",
                             u8"b",
                             u8"\u0c2c\u0c4d",
                             u8"f",
                             u8"\u0c2b\u0c4d",
                             u8"\u0c2a\u0c4d\u001d?h",
                             u8"\u0c2b\u0c4d",
                             u8"P",
                             u8"\u0c2b\u0c4d",
                             u8"p",
                             u8"\u0c2a\u0c4d",
                             u8"\u0c28\u0c4d\u001d?G",
                             u8"\u0c02\u0c18\u0c4d",
                             u8"\u0c28\u0c4d\u001d?g",
                             u8"\u0c02\u0c17\u0c4d",
                             u8"\u0c28\u0c4d\u001d?K",
                             u8"\u0c02\u0c16\u0c4d",
                             u8"\u0c28\u0c4d\u001d?k",
                             u8"\u0c02\u0c15\u0c4d",
                             u8"\u0c28\u0c4d\u001d?J",
                             u8"\u0c02\u0c1d\u0c4d",
                             u8"\u0c28\u0c4d\u001d?j",
                             u8"\u0c02\u0c1c\u0c4d",
                             u8"\u0c28\u0c4d\u001d?Ch",
                             u8"\u0c02\u0c1b\u0c4d",
                             u8"\u0c28\u0c4d\u001d?ch",
                             u8"\u0c02\u0c1a\u0c4d",
                             u8"\u0c28\u0c4d\u001d?C",
                             u8"\u0c02\u0c1b\u0c4d",
                             u8"\u0c28\u0c4d\u001d?c",
                             u8"\u0c02\u0c1a\u0c4d",
                             u8"\u0c28\u0c4d\u001d?D",
                             u8"\u0c02\u0c21\u0c4d",
                             u8"\u0c28\u0c4d\u001d?T",
                             u8"\u0c02\u0c1f\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?g",
                             u8"\u0c19\u0c4d\u0c17\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?k",
                             u8"\u0c19\u0c4d\u0c15\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?j",
                             u8"\u0c1e\u0c4d\u0c1c\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?Ch",
                             u8"\u0c1e\u0c4d\u0c1b\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?ch",
                             u8"\u0c1e\u0c4d\u0c1a\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?C",
                             u8"\u0c1e\u0c4d\u0c1b\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?c",
                             u8"\u0c1e\u0c4d\u0c1a\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?D",
                             u8"\u0c23\u0c4d\u0c21\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?T",
                             u8"\u0c23\u0c4d\u0c1f\u0c4d",
                             u8"\\|",
                             u8"\u0964",
                             u8"\u0964\u001d?\\|",
                             u8"\u0965"};
const unsigned int kTransformsLen = base::size(kTransforms);
const char* kHistoryPrune = "C|c";

}  // namespace te_phone

==> chromium_102.0.5005.61.orig.tar.xz: chromium-102.0.5005.61/ash/services/ime/public/cpp/rulebased/def/te_phone.cc <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ash/services/ime/public/cpp/rulebased/def/te_phone.h"

#include <iterator>

namespace te_phone {

const char* kId = "te_phone";
bool kIs102 = false;
const char* kTransforms[] = {u8"([\u0c15-\u0c39])\u001d?u",
                             u8"\\1\u0c4c",
                             u8"\u0c4a\u001d?o",
                             u8"\u0c4b",
                             u8"\u0c4d\u001d?O",
                             u8"\u0c4b",
                             u8"\u0c4d\u001d?o",
                             u8"\u0c4a",
                             u8"([\u0c15-\u0c39])\u001d?i",
                             u8"\\1\u0c48",
                             u8"\u0c46\u001d?e",
                             u8"\u0c40",
                             u8"\u0c4d\u001d?E",
                             u8"\u0c47",
                             u8"\u0c4d\u001d?e",
                             u8"\u0c46",
                             u8"\u0c4d\u0c33\u0c4d\u0c33\u0c4d\u001d?I",
                             u8"\u0c63",
                             u8"\u0c4d\u0c33\u0c4d\u001d?\\^I",
                             u8"\u0c63",
                             u8"\u0c4d\u0c33\u0c4d\u0c33\u0c4d\u001d?i",
                             u8"\u0c62",
                             u8"\u0c4d\u0c33\u0c4d\u001d?\\^i",
                             u8"\u0c62",
                             u8"\u0c43\u001d?I",
                             u8"\u0c44",
                             u8"\u0c43\u001d?\\^I",
                             u8"\u0c44",
                             u8"\u0c43\u001d?R",
                             u8"\u0c44",
                             u8"\u0c43\u001d?\\^i",
                             u8"\u0c43",
                             u8"\u0c44\u001d?i",
                             u8"\u0c43",
                             u8"\u0c4d\u001d?R",
                             u8"\u0c43",
                             u8"\u0c41\u001d?u",
                             u8"\u0c42",
                             u8"\u0c4d\u001d?U",
                             u8"\u0c42",
                             u8"\u0c4d\u001d?u",
                             u8"\u0c41",
                             u8"\u0c3f\u001d?i",
                             u8"\u0c40",
                             u8"\u0c4d\u001d?I",
                             u8"\u0c40",
                             u8"\u0c4d\u001d?i",
                             u8"\u0c3f",
                             u8"([\u0c15-\u0c39])\u001d?a",
                             u8"\\1\u0c3e",
                             u8"\u0c4d\u001d?A",
                             u8"\u0c3e",
                             u8"\u0c4d\u001d?a",
                             u8"",
                             u8"\\.a",
                             u8"\u0c3d",
                             u8"\\.m",
                             u8"\u0c02",
                             u8"\\.z",
                             u8"",
                             u8"\\.N",
                             u8"\u0c01",
                             u8"\u0c4d\u001d?\\.h",
                             u8"\u0c4d\u200c",
                             u8"\\.h",
                             u8"\u0c4d\u200c",
                             u8"@M",
                             u8"\u0c02",
                             u8"@h",
                             u8"\u0c03",
                             u8"@2",
                             u8"\u0c3d",
                             u8"M",
                             u8"\u0c02",
                             u8"H",
                             u8"\u0c03",
                             u8"\u0c15\u0c4d\u001d?H",
                             u8"\u0cf1",
                             u8"\u0c2a\u0c4d\u001d?H",
                             u8"\u0cf2",
                             u8"\u0c05\u001d?u",
                             u8"\u0c14",
                             u8"\u0c12\u001d?o",
                             u8"\u0c13",
                             u8"O",
                             u8"\u0c13",
                             u8"o",
                             u8"\u0c12",
                             u8"\u0c05\u001d?i",
                             u8"\u0c10",
                             u8"\u0c0e\u001d?e",
                             u8"\u0c08",
                             u8"E",
                             u8"\u0c0f",
                             u8"e",
                             u8"\u0c0e",
                             u8"\u0c33\u0c4d\u0c33\u0c4d\u001d?I",
                             u8"\u0c61",
                             u8"\u0c33\u0c4d\u001d?\\^I",
                             u8"\u0c61",
                             u8"\u0c33\u0c4d\u0c33\u0c4d\u001d?i",
                             u8"\u0c0c",
                             u8"\u0c33\u0c4d\u001d?i",
                             u8"\u0c0c",
                             u8"\u0c60\u001d?I",
                             u8"\u0c60",
                             u8"\u0c0b\u001d?R",
                             u8"\u0c60",
                             u8"R",
                             u8"\u0c0b",
                             u8"\u0c09\u001d?u",
                             u8"\u0c0a",
                             u8"U",
                             u8"\u0c0a",
                             u8"u",
                             u8"\u0c09",
                             u8"\u0c07\u001d?i",
                             u8"\u0c08",
                             u8"I",
                             u8"\u0c08",
                             u8"i",
                             u8"\u0c07",
                             u8"A",
                             u8"\u0c06",
                             u8"\u0c05\u001d?a",
                             u8"\u0c06",
                             u8"a",
                             u8"\u0c05",
                             u8"\u0c15\u0c4d\u0c37\u0c4d\u001d?h",
                             u8"\u0c15\u0c4d\u0c37\u0c4d",
                             u8"\u0c17\u0c4d\u001d?Y",
                             u8"\u0c1c\u0c4d\u0c1e\u0c4d",
                             u8"\u0c1c\u0c4d\u001d?n",
                             u8"\u0c1c\u0c4d\u0c1e\u0c4d",
                             u8"\u0c15\u0c4d\u0c38\u0c4d\u001d?h",
                             u8"\u0c15\u0c4d\u0c37\u0c4d",
                             u8"\u0c15\u0c4d\u001d?S",
                             u8"\u0c15\u0c4d\u0c37\u0c4d",
                             u8"x",
                             u8"\u0c15\u0c4d\u0c37\u0c4d",
                             u8"h",
                             u8"\u0c39\u0c4d",
                             u8"\u0c36\u0c4d\u001d?h",
                             u8"\u0c37\u0c4d",
                             u8"S",
                             u8"\u0c36\u0c4d",
                             u8"z",
                             u8"\u0c36\u0c4d",
                             u8"\u0c38\u0c4d\u001d?h",
                             u8"\u0c36\u0c4d",
                             u8"s",
                             u8"\u0c38\u0c4d",
                             u8"v",
                             u8"\u0c35\u0c4d",
                             u8"w",
                             u8"\u0c35\u0c4d",
                             u8"L",
                             u8"\u0c33\u0c4d",
                             u8"\\.L",
                             u8"\u0c33\u0c4d",
                             u8"l",
                             u8"\u0c32\u0c4d",
                             u8"r",
                             u8"\u0c30\u0c4d",
                             u8"\\.r",
                             u8"\u0c31\u0c4d",
                             u8"y",
                             u8"\u0c2f\u0c4d",
                             u8"~N",
                             u8"\u0c19\u0c4d",
                             u8"\u0c17\u0c4d\u001d?h",
                             u8"\u0c18\u0c4d",
                             u8"G",
                             u8"\u0c18\u0c4d",
                             u8"\\.g",
                             u8"\u0c17\u0c4d",
                             u8"g",
                             u8"\u0c17\u0c4d",
                             u8"\\.K",
                             u8"\u0c16\u0c4d",
                             u8"K",
                             u8"\u0c16\u0c4d",
                             u8"\u0c15\u0c4d\u001d?h",
                             u8"\u0c16\u0c4d",
                             u8"q",
                             u8"\u0c15\u0c4d",
                             u8"k",
                             u8"\u0c15\u0c4d",
                             u8"~n",
                             u8"\u0c1e\u0c4d",
                             u8"\u0c1c\u0c4d\u001d?h",
                             u8"\u0c1d\u0c4d",
                             u8"J",
                             u8"\u0c1d\u0c4d",
                             u8"\\.j",
                             u8"\u0c1c\u0c4d",
                             u8"j",
                             u8"\u0c1c\u0c4d",
                             u8"\u0c1a\u0c4d\u001d?h",
                             u8"\u0c1b\u0c4d",
                             u8"Ch",
                             u8"\u0c1b\u0c4d",
                             u8"C",
                             u8"\u0c1b\u0c4d",
                             u8"ch",
                             u8"\u0c1a\u0c4d",
                             u8"c",
                             u8"\u0c1a\u0c4d",
                             u8"N",
                             u8"\u0c23\u0c4d",
                             u8"\u0c21\u0c4d\u001d?h",
                             u8"\u0c22\u0c4d",
                             u8"\\.D",
                             u8"\u0c21\u0c4d",
                             u8"D",
                             u8"\u0c21\u0c4d",
                             u8"\u0c1f\u0c4d\u001d?h",
                             u8"\u0c20\u0c4d",
                             u8"T",
                             u8"\u0c1f\u0c4d",
                             u8"n",
                             u8"\u0c28\u0c4d",
                             u8"\u0c26\u0c4d\u001d?h",
                             u8"\u0c27\u0c4d",
                             u8"d",
                             u8"\u0c26\u0c4d",
                             u8"\u0c24\u0c4d\u001d?h",
                             u8"\u0c25\u0c4d",
                             u8"t",
                             u8"\u0c24\u0c4d",
                             u8"m",
                             u8"\u0c2e\u0c4d",
                             u8"\u0c2c\u0c4d\u001d?h",
                             u8"\u0c2d\u0c4d",
                             u8"B",
                             u8"\u0c2d\u0c4d",
                             u8"b",
                             u8"\u0c2c\u0c4d",
                             u8"f",
                             u8"\u0c2b\u0c4d",
                             u8"\u0c2a\u0c4d\u001d?h",
                             u8"\u0c2b\u0c4d",
                             u8"P",
                             u8"\u0c2b\u0c4d",
                             u8"p",
                             u8"\u0c2a\u0c4d",
                             u8"\u0c28\u0c4d\u001d?G",
                             u8"\u0c02\u0c18\u0c4d",
                             u8"\u0c28\u0c4d\u001d?g",
                             u8"\u0c02\u0c17\u0c4d",
                             u8"\u0c28\u0c4d\u001d?K",
                             u8"\u0c02\u0c16\u0c4d",
                             u8"\u0c28\u0c4d\u001d?k",
                             u8"\u0c02\u0c15\u0c4d",
                             u8"\u0c28\u0c4d\u001d?J",
                             u8"\u0c02\u0c1d\u0c4d",
                             u8"\u0c28\u0c4d\u001d?j",
                             u8"\u0c02\u0c1c\u0c4d",
                             u8"\u0c28\u0c4d\u001d?Ch",
                             u8"\u0c02\u0c1b\u0c4d",
                             u8"\u0c28\u0c4d\u001d?ch",
                             u8"\u0c02\u0c1a\u0c4d",
                             u8"\u0c28\u0c4d\u001d?C",
                             u8"\u0c02\u0c1b\u0c4d",
                             u8"\u0c28\u0c4d\u001d?c",
                             u8"\u0c02\u0c1a\u0c4d",
                             u8"\u0c28\u0c4d\u001d?D",
                             u8"\u0c02\u0c21\u0c4d",
                             u8"\u0c28\u0c4d\u001d?T",
                             u8"\u0c02\u0c1f\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?g",
                             u8"\u0c19\u0c4d\u0c17\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?k",
                             u8"\u0c19\u0c4d\u0c15\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?j",
                             u8"\u0c1e\u0c4d\u0c1c\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?Ch",
                             u8"\u0c1e\u0c4d\u0c1b\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?ch",
                             u8"\u0c1e\u0c4d\u0c1a\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?C",
                             u8"\u0c1e\u0c4d\u0c1b\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?c",
                             u8"\u0c1e\u0c4d\u0c1a\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?D",
                             u8"\u0c23\u0c4d\u0c21\u0c4d",
                             u8"\u0c28\u0c4d\u0c28\u0c4d\u001d?T",
                             u8"\u0c23\u0c4d\u0c1f\u0c4d",
                             u8"\\|",
                             u8"\u0964",
                             u8"\u0964\u001d?\\|",
                             u8"\u0965"};
const unsigned int kTransformsLen = std::size(kTransforms);
const char* kHistoryPrune = "C|c";

}  // namespace te_phone
